## `valency-anndata` methods

### ::: valency_anndata.preprocessing.rebuild_vote_matrix

### ::: valency_anndata.preprocessing.calculate_qc_metrics

### ::: valency_anndata.preprocessing.impute


## `scanpy` methods (inherited)

!!! note

    These methods are simply quick convenience wrappers around methods in `scanpy`, a tool for single-cell gene expression. They will use terms like "cells", "genes" and "counts", but you can think of these as "participants", "statements" and "votes". 

See [scanpy.pp][] for more methods you can experiment with via the `val.scanpy.pp` namespace.

### ::: valency_anndata.preprocessing.neighbors